@@ -21,11 +21,10 @@
 
 #include "outputconfig.h"
 #include "resolutionslider.h"
-#include "collapsablebutton.h"
 #include "utils.h"
 #include "kcm_screen_debug.h"
 
-#include <QtCore/QStringBuilder>
+#include <QStringBuilder>
 #include <QFormLayout>
 #include <QComboBox>
 #include <QCheckBox>
@@ -88,7 +87,7 @@ void OutputConfig::initUi()
                 mScale->setCurrentIndex(index);
             });
 
-    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
     QVBoxLayout *vbox = new QVBoxLayout(this);
     mTitle = new QLabel(this);
@@ -116,10 +115,15 @@ void OutputConfig::initUi()
     formLayout->addRow(i18n("Resolution:"), mResolution);
 
     mRotation = new QComboBox(this);
-    mRotation->addItem(QIcon::fromTheme(QStringLiteral("arrow-up")), i18n("Normal"), KScreen::Output::None);
-    mRotation->addItem(QIcon::fromTheme(QStringLiteral("arrow-right")), i18n("90° Clockwise"), KScreen::Output::Right);
-    mRotation->addItem(QIcon::fromTheme(QStringLiteral("arrow-down")), i18n("Upside Down"), KScreen::Output::Inverted);
-    mRotation->addItem(QIcon::fromTheme(QStringLiteral("arrow-left")), i18n("90° Counterclockwise"), KScreen::Output::Left);
+    QIcon previewIcon = QIcon::fromTheme(QStringLiteral("view-preview"));
+    QPixmap previewPixmap = previewIcon.pixmap(mRotation->iconSize());
+    QIcon previewRotatedCounterClockwise = QIcon(previewPixmap.transformed(QMatrix(0.0, 1.0, 1.0, 0.0, 0.0, 0.0)));
+    QIcon previewRotatedClockwise = QIcon(previewPixmap.transformed(QMatrix(0.0, -1.0, -1.0, 0.0, 0.0, 0.0)));
+    QIcon previewRotatedUpSideDown = QIcon(previewPixmap.transformed(QMatrix(-1.0, 0.0, 0.0, -1.0, 0.0, 0.0)));
+    mRotation->addItem(previewIcon, i18n("No Rotation"), KScreen::Output::None);
+    mRotation->addItem(previewRotatedClockwise, i18n("90° Clockwise"), KScreen::Output::Right);
+    mRotation->addItem(previewRotatedUpSideDown, i18n("Upside Down"), KScreen::Output::Inverted);
+    mRotation->addItem(previewRotatedCounterClockwise, i18n("90° Counterclockwise"), KScreen::Output::Left);
     connect(mRotation, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &OutputConfig::slotRotationChanged);
     mRotation->setCurrentIndex(mRotation->findData(mOutput->rotation()));
@@ -139,28 +143,12 @@ void OutputConfig::initUi()
         formLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum));
     }
 
-    CollapsableButton *advancedButton = new CollapsableButton(i18n("Advanced Settings"), this);
-    advancedButton->setCollapsed(true);
-    vbox->addWidget(advancedButton);
-
-    QWidget *advancedWidget = new QWidget(this);
-    int leftMargin, topMargin, rightMargin, bottomMargin;
-    advancedWidget->getContentsMargins(&leftMargin, &topMargin, &rightMargin, &bottomMargin);
-    advancedWidget->setContentsMargins(25, topMargin, rightMargin, bottomMargin);
-    vbox->addWidget(advancedWidget);
-    advancedButton->setWidget(advancedWidget);
-
-    formLayout = new QFormLayout(advancedWidget);
-    advancedWidget->setLayout(formLayout);
-
-    mRefreshRate = new QComboBox(advancedWidget);
+    mRefreshRate = new QComboBox(this);
     mRefreshRate->addItem(i18n("Auto"), -1);
     formLayout->addRow(i18n("Refresh rate:"), mRefreshRate);
     slotResolutionChanged(mResolution->currentResolution());
     connect(mRefreshRate, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &OutputConfig::slotRefreshRateChanged);
-
-    vbox->addStretch(2);
 }
 
 void OutputConfig::setOutput(const KScreen::OutputPtr &output)
@@ -205,12 +193,12 @@ void OutputConfig::slotResolutionChanged(const QSize &size)
     for (int i = 0, total = modes.count(); i < total; ++i) {
         const KScreen::ModePtr mode = modes.at(i);
         mRefreshRate->addItem(i18n("%1 Hz", QLocale().toString(mode->refreshRate(), 'f', 2)), mode->id());
-
         // If selected refresh rate is other then what we consider the "Auto" value
         // - that is it's not the highest resolution - then select it, otherwise
         // we stick with "Auto"
         if (mode == selectedMode && i > 1) {
-            mRefreshRate->setCurrentIndex(i);
+            // i + 1 since 0 is auto
+            mRefreshRate->setCurrentIndex(i + 1);
         }
     }
 
